@@ -30,6 +30,7 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
+        global feature_name
         super().__init__()
 
     def get_file(self, storage_json_file_name=None):
@@ -37,7 +38,6 @@ class accuinsight(Common):
         save_path, StorageInfo, target_name = super().get_file(storage_json_file_name)
 
     def set_features(self, feature_names):
-        global feature_name
         feature_name = super().set_features(feature_names)
 
     class add_experiment(object):
@@ -155,7 +155,11 @@ class accuinsight(Common):
             if self.shap_on:
                 if not feature_name:
                     try:
-                        self.feature_name = get.feature_name(save_path, StorageInfo, target_name)
+                        if self.data is not None:
+                            self.feature_name = get.feature_name(save_path, StorageInfo, target_name, data=self.data)
+                            self.data = None
+                        else:
+                            self.feature_name = get.feature_name(save_path, StorageInfo, target_name)
                     except:
                         self.feature_name = None
                 else:
