@@ -52,7 +52,12 @@ class accuinsight(Common):
             shap_on = True
             if self.feature_name is None:
                 try:
-                    feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
+                    if self.data is not None:
+                        feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name,
+                                                        data=self.data)
+                        self.data = None
+                    else:
+                        feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
 
                 except:
                     pass      # when user did not use <get_file> or <set_feature> function
@@ -108,9 +113,6 @@ class accuinsight(Common):
                 opt_key = list(opt.keys())[1:]
                 opt_result = {k: np.float64(opt[k]) for k in opt_key}
 
-                # self.run_id = func.get_run_id()
-                # self.model_type = get.model_type(self.model)
-
                 self.model_summary['data_version'] = endpoint
                 self.model_summary['model_description'] = description
                 self.model_summary['logging_time'] = get_time.logging_time()
@@ -122,7 +124,6 @@ class accuinsight(Common):
                 else:
                     self.model_summary['loss_function'] = self.model.loss
                 self.model_summary['optimizer_info'] = {opt['name']: opt_result}
-                # self.model_summary['optimizer_info'] = {type(self.model.optimizer).__name__: self.model.optimizer.get_config()}
 
                 '''[get best model] on_train_begin '''
                 self.best_weights = self.model.get_weights()
@@ -212,7 +213,7 @@ class accuinsight(Common):
                 if self.verbose > 0:
                     print('Using epoch %05d with %s: %0.5f' % (self.best_epochs, self.monitor, self.best))
                 self.model.set_weights(self.best_weights)  # set best model's weights
-                
+
 #                self.model_summary = OrderedDict()
 #                self.model_summary['data_version'] = endpoint
 #                self.model_summary['model_description'] = description
