@@ -4,6 +4,7 @@ import numpy as np
 from collections import OrderedDict
 from Accuinsight.modeler.core import ModelType
 
+
 def as_array(dat):
     if 'ndarray' in str(type(dat)):
         pass
@@ -11,6 +12,7 @@ def as_array(dat):
         dat = np.array(dat)
     return(dat) 
 
+
 def get_model_name(model):
     model_name = str(model)
     
@@ -23,8 +25,8 @@ def get_model_name(model):
         
     return(model_name)
 
-def shap_value(model, dat, feature_name):    
-      
+
+def shap_value(model, dat, feature_name):
     dat = as_array(dat)
         
     if feature_name is None:                               
@@ -57,5 +59,5 @@ def shap_value(model, dat, feature_name):
     else:
         raise ValueError("The dimensions of the train data and the feature name do not match. \nPlease use 'set_feature()' function for setting feature names.")
         
-    return(dict(feature_contribution))
+    return dict(feature_contribution)
 
