@@ -144,27 +144,35 @@ def is_classification(model_name):
             raise ValueError('현재 설정한 loss는 지원되지 않습니다. 관리자에게 문의하십시오.')
 
 
-def feature_name(savedPath, StorageInfo, targetName):
-    if StorageInfo is None:
-        fileType = savedPath.split('.')[-1]
+def feature_name(savedPath, StorageInfo, targetName, data=None):
+    if data is not None:
+        try:
+            feature_name = list(data.keys())
+        except AttributeError:
+            raise TypeError('지원하지 않는 데이터 형식입니다. 현재 지원하는 데이터 형식은 json과 pandas.core.frame.DataFrame입니다.')
 
-    elif 'host' in StorageInfo:  # HDFS
-        fileType = StorageInfo['filePath'].split('.')[1]
-
-    else:  # AWS S3
-        fileType = StorageInfo['fileName'].split('.')[1]
-        
-    if fileType == 'json':
-        with open(savedPath) as jsonFile:
-            json_data = json.load(jsonFile)
-        feature_name = list(json_data.keys())
-    elif fileType == 'csv':
-        feature_name = list(pd.read_csv(savedPath).columns)
-        if 'Unnamed: 0' in feature_name and feature_name[0]=='Unnamed: 0':
-            feature_name.remove('Unnamed: 0')
     else:
-        raise TypeError('{type}은 지원하지 않는 데이터 형식입니다. 현재 지원하는 데이터 형식은 json과 csv입니다.'.format(type=fileType))
+        if StorageInfo is None:
+            fileType = savedPath.split('.')[-1]
+
+        elif 'host' in StorageInfo:  # HDFS
+            fileType = StorageInfo['filePath'].split('.')[1]
+
+        else:  # AWS S3
+            fileType = StorageInfo['fileName'].split('.')[1]
+        
+        if fileType == 'json':
+            with open(savedPath) as jsonFile:
+                json_data = json.load(jsonFile)
+            feature_name = list(json_data.keys())
+        elif fileType == 'csv':
+            feature_name = list(pd.read_csv(savedPath).columns)
+            if 'Unnamed: 0' in feature_name and feature_name[0] == 'Unnamed: 0':
+                feature_name.remove('Unnamed: 0')
+        else:
+            raise TypeError('{type}은 지원하지 않는 데이터 형식입니다. 현재 지원하는 데이터 형식은 json과 csv입니다.'.format(type=fileType))
     
     if targetName in feature_name:
         feature_name.remove(targetName)
+
     return feature_name
